==> apache-cxf-3.4.7-src.tar.gz: apache-cxf-3.4.7-src/core/src/test/java/org/apache/cxf/configuration/foo/Foo.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.configuration.foo;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for foo complex type.
 *
 * <p>The following schema fragment specifies the expected content contained within this class.
 *
 * <pre>
 * &lt;complexType name="foo">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="position" type="{http://cxf.apache.org/configuration/foo}point" minOccurs="0"/>
 *         &lt;element name="address" type="{http://cxf.apache.org/configuration/foo}address" minOccurs="0"/>
 *         &lt;element name="name" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="intDefault" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *         &lt;element name="intNoDefault" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 *
 *
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "foo",
    propOrder = {
        "position",
        "address",
        "name",
        "intDefault",
        "intNoDefault"
    })
public class Foo {

    protected Point position;
    protected Address address;
    protected String name;
    @XmlElement(defaultValue = "22")
    protected Integer intDefault;
    protected Integer intNoDefault;

    /**
     * Gets the value of the position property.
     *
     * @return
     *     possible object is
     *     {@link Point }
     *
     */
    public Point getPosition() {
        return position;
    }

    /**
     * Sets the value of the position property.
     *
     * @param value
     *     allowed object is
     *     {@link Point }
     *
     */
    public void setPosition(Point value) {
        this.position = value;
    }

    /**
     * Gets the value of the address property.
     *
     * @return
     *     possible object is
     *     {@link Address }
     *
     */
    public Address getAddress() {
        return address;
    }

    /**
     * Sets the value of the address property.
     *
     * @param value
     *     allowed object is
     *     {@link Address }
     *
     */
    public void setAddress(Address value) {
        this.address = value;
    }

    /**
     * Gets the value of the name property.
     *
     * @return
     *     possible object is
     *     {@link String }
     *
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the value of the name property.
     *
     * @param value
     *     allowed object is
     *     {@link String }
     *
     */
    public void setName(String value) {
        this.name = value;
    }

    /**
     * Gets the value of the intDefault property.
     *
     * @return
     *     possible object is
     *     {@link Integer }
     *
     */
    public Integer getIntDefault() {
        return intDefault;
    }

    /**
     * Sets the value of the intDefault property.
     *
     * @param value
     *     allowed object is
     *     {@link Integer }
     *
     */
    public void setIntDefault(Integer value) {
        this.intDefault = value;
    }

    /**
     * Gets the value of the intNoDefault property.
     *
     * @return
     *     possible object is
     *     {@link Integer }
     *
     */
    public Integer getIntNoDefault() {
        return intNoDefault;
    }

    /**
     * Sets the value of the intNoDefault property.
     *
     * @param value
     *     allowed object is
     *     {@link Integer }
     *
     */
    public void setIntNoDefault(Integer value) {
        this.intNoDefault = value;
    }

}

==> apache-cxf-4.0.7-src.tar.gz: apache-cxf-4.0.7-src/core/src/test/java/org/apache/cxf/configuration/foo/Foo.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.configuration.foo;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for foo complex type.
 *
 * <p>The following schema fragment specifies the expected content contained within this class.
 *
 * <pre>
 * &lt;complexType name="foo">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="position" type="{http://cxf.apache.org/configuration/foo}point" minOccurs="0"/>
 *         &lt;element name="address" type="{http://cxf.apache.org/configuration/foo}address" minOccurs="0"/>
 *         &lt;element name="name" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *         &lt;element name="intDefault" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *         &lt;element name="intNoDefault" type="{http://www.w3.org/2001/XMLSchema}int" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 *
 *
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "foo",
    propOrder = {
        "position",
        "address",
        "name",
        "intDefault",
        "intNoDefault"
    })
public class Foo {

    protected Point position;
    protected Address address;
    protected String name;
    @XmlElement(defaultValue = "22")
    protected Integer intDefault;
    protected Integer intNoDefault;

    /**
     * Gets the value of the position property.
     *
     * @return
     *     possible object is
     *     {@link Point }
     *
     */
    public Point getPosition() {
        return position;
    }

    /**
     * Sets the value of the position property.
     *
     * @param value
     *     allowed object is
     *     {@link Point }
     *
     */
    public void setPosition(Point value) {
        this.position = value;
    }

    /**
     * Gets the value of the address property.
     *
     * @return
     *     possible object is
     *     {@link Address }
     *
     */
    public Address getAddress() {
        return address;
    }

    /**
     * Sets the value of the address property.
     *
     * @param value
     *     allowed object is
     *     {@link Address }
     *
     */
    public void setAddress(Address value) {
        this.address = value;
    }

    /**
     * Gets the value of the name property.
     *
     * @return
     *     possible object is
     *     {@link String }
     *
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the value of the name property.
     *
     * @param value
     *     allowed object is
     *     {@link String }
     *
     */
    public void setName(String value) {
        this.name = value;
    }

    /**
     * Gets the value of the intDefault property.
     *
     * @return
     *     possible object is
     *     {@link Integer }
     *
     */
    public Integer getIntDefault() {
        return intDefault;
    }

    /**
     * Sets the value of the intDefault property.
     *
     * @param value
     *     allowed object is
     *     {@link Integer }
     *
     */
    public void setIntDefault(Integer value) {
        this.intDefault = value;
    }

    /**
     * Gets the value of the intNoDefault property.
     *
     * @return
     *     possible object is
     *     {@link Integer }
     *
     */
    public Integer getIntNoDefault() {
        return intNoDefault;
    }

    /**
     * Sets the value of the intNoDefault property.
     *
     * @param value
     *     allowed object is
     *     {@link Integer }
     *
     */
    public void setIntNoDefault(Integer value) {
        this.intNoDefault = value;
    }

}
